@@ -65,6 +65,10 @@ class CompressInterface():
 		'''uncompress file'''
 		raise NotImplemented()
 
+	def extractall(self, path):
+		'''uncompress archive'''
+		raise NotImplemented()
+
 	def __iter__(self):
 		raise NotImplemented()
 
@@ -101,6 +105,9 @@ class CompressTar(CompressInterface):
 		
 		return (res.read(), infos)
 
+	def extractall(self, path):
+		self.__instance.extractall(path)
+
 	def __iter__(self):
 		return iter(self.__instance.getnames())
 
@@ -134,6 +141,9 @@ class CompressZip(CompressInterface):
 		infos.mtime = time.mktime(datetime.datetime(*self.__instance.getinfo(file).date_time[0:6]).timetuple())
 		return (self.__instance.read(file), infos)
 
+	def extractall(self, path):
+		self.__instance.extractall(path)
+
 	def __iter__(self):
 		for item in self.__instance.namelist():
 			if item.endswith('/'):
